@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-    
 def attach(vmanage, request):
     """
     Attach service chain to cluster
@@ -14,8 +11,8 @@ def attach(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicechain/attach"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/colocation/servicechain/attach"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 
 def autoAttach(vmanage, request):
@@ -31,8 +28,8 @@ def autoAttach(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicechain/autoattach"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/colocation/servicechain/autoattach"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 
 def detach(vmanage, request):
@@ -48,8 +45,8 @@ def detach(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicechain/detach"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, request)
+    endpoint = f"dataservice/colocation/servicechain/detach"
+    response = vmanage.apiCall("PUT", endpoint, request)
     return response
 
 def getEdgeDevices(vmanage):
@@ -64,8 +61,8 @@ def getEdgeDevices(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicechain/edge/devices"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/servicechain/edge/devices"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getpnfDevices(vmanage, pnfDeviceType):
@@ -81,6 +78,6 @@ def getpnfDevices(vmanage, pnfDeviceType):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicechain/edge/pnfdevices?pnfDeviceType={pnfDeviceType}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/servicechain/edge/pnfdevices?pnfDeviceType={pnfDeviceType}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
