@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getServiceChain(vmanage, serviceGroupName):
     """
     Get service chain by name
@@ -14,8 +11,8 @@ def getServiceChain(vmanage, serviceGroupName):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicegroup?serviceGroupName={serviceGroupName}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/servicegroup?serviceGroupName={serviceGroupName}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def update(vmanage, servicegroup):
@@ -31,8 +28,8 @@ def update(vmanage, servicegroup):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicegroup"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, servicegroup)
+    endpoint = f"dataservice/colocation/servicegroup"
+    response = vmanage.apiCall("PUT", endpoint, servicegroup)
     return response
 
 def create(vmanage, servicegroup):
@@ -48,8 +45,8 @@ def create(vmanage, servicegroup):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicegroup"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, servicegroup)
+    endpoint = f"dataservice/colocation/servicegroup"
+    response = vmanage.apiCall("POST", endpoint, servicegroup)
     return response
 
 def getGroupInCluster(vmanage, ClusterId, UserGroupName):
@@ -66,8 +63,8 @@ def getGroupInCluster(vmanage, ClusterId, UserGroupName):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicegroup/attached?ClusterId={ClusterId}&UserGroupName={UserGroupName}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/servicegroup/attached?ClusterId={ClusterId}&UserGroupName={UserGroupName}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getDefaultChain(vmanage):
@@ -82,8 +79,8 @@ def getDefaultChain(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicegroup/servicechain/default"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/servicegroup/servicechain/default"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getAvailableChains(vmanage):
@@ -98,8 +95,8 @@ def getAvailableChains(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicegroup/servicechains"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/colocation/servicegroup/servicechains"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def delete(vmanage, name):
@@ -115,6 +112,6 @@ def delete(vmanage, name):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/colocation/servicegroup/{name}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/colocation/servicegroup/{name}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
