@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getCortexStatus(vmanage):
     """
     Get Cortex List
@@ -13,8 +10,8 @@ def getCortexStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cortex"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cortex"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def authAzureCredAndAdd(vmanage, credential):
@@ -30,8 +27,8 @@ def authAzureCredAndAdd(vmanage, credential):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cortex/cloud/authenticate"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, credential)
+    endpoint = f"dataservice/template/cortex/cloud/authenticate"
+    response = vmanage.apiCall("POST", endpoint, credential)
     return response
 
 def getMappedWanRG(vmanage, accountid, cloudregion):
@@ -48,8 +45,8 @@ def getMappedWanRG(vmanage, accountid, cloudregion):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cortex/map?accountid={accountid}&cloudregion={cloudregion}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cortex/map?accountid={accountid}&cloudregion={cloudregion}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def syncWanRG(vmanage, wanRG):
@@ -65,8 +62,8 @@ def syncWanRG(vmanage, wanRG):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cortex/sync"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, wanRG)
+    endpoint = f"dataservice/template/cortex/sync"
+    response = vmanage.apiCall("POST", endpoint, wanRG)
     return response
 
 def getWanRG(vmanage, accountid):
@@ -82,8 +79,8 @@ def getWanRG(vmanage, accountid):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cortex/wanrg?accountid={accountid}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cortex/wanrg?accountid={accountid}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editWanRG(vmanage, wanRG):
@@ -99,8 +96,8 @@ def editWanRG(vmanage, wanRG):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cortex/wanrg"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, wanRG)
+    endpoint = f"dataservice/template/cortex/wanrg"
+    response = vmanage.apiCall("PUT", endpoint, wanRG)
     return response
 
 def saveWanRG(vmanage, wanRG):
@@ -116,8 +113,8 @@ def saveWanRG(vmanage, wanRG):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cortex/wanrg"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, wanRG)
+    endpoint = f"dataservice/template/cortex/wanrg"
+    response = vmanage.apiCall("POST", endpoint, wanRG)
     return response
 
 def deleteWanRG(vmanage, wanRG):
@@ -133,6 +130,6 @@ def deleteWanRG(vmanage, wanRG):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cortex/wanrg"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint, wanRG)
+    endpoint = f"dataservice/template/cortex/wanrg"
+    response = vmanage.apiCall("DELETE", endpoint, wanRG)
     return response
