@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getCloudXStatus(vmanage):
     """
     Get CloudX feature list
@@ -13,8 +10,8 @@ def getCloudXStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def addCloudxType(vmanage, cloudx, type):
@@ -31,8 +28,8 @@ def addCloudxType(vmanage, cloudx, type):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/addcloudx/{type}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, cloudx)
+    endpoint = f"dataservice/template/cloudx/addcloudx/{type}"
+    response = vmanage.apiCall("POST", endpoint, cloudx)
     return response
 
 def getAttachedClientList(vmanage):
@@ -47,8 +44,8 @@ def getAttachedClientList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/attachedclient"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx/attachedclient"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getAttachedDiaList(vmanage):
@@ -63,8 +60,8 @@ def getAttachedDiaList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/attacheddia"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx/attacheddia"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getAttachedGwList(vmanage):
@@ -79,8 +76,8 @@ def getAttachedGwList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/attachedgateway"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx/attachedgateway"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getCloudXAvailableApps(vmanage):
@@ -95,8 +92,8 @@ def getCloudXAvailableApps(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/availableapps"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx/availableapps"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getSiteList(vmanage):
@@ -111,8 +108,8 @@ def getSiteList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/clientlist"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx/clientlist"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getDiaList(vmanage):
@@ -127,8 +124,8 @@ def getDiaList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/dialist"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx/dialist"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getGwList(vmanage):
@@ -143,8 +140,8 @@ def getGwList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/gatewaylist"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx/gatewaylist"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def addCloudxInterfaces(vmanage, cloudx):
@@ -160,8 +157,8 @@ def addCloudxInterfaces(vmanage, cloudx):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/interfaces"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, cloudx)
+    endpoint = f"dataservice/template/cloudx/interfaces"
+    response = vmanage.apiCall("POST", endpoint, cloudx)
     return response
 
 def getApps(vmanage):
@@ -176,8 +173,8 @@ def getApps(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/manage/apps"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx/manage/apps"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editApps(vmanage, appVPN):
@@ -193,8 +190,8 @@ def editApps(vmanage, appVPN):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/manage/apps"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, appVPN)
+    endpoint = f"dataservice/template/cloudx/manage/apps"
+    response = vmanage.apiCall("PUT", endpoint, appVPN)
     return response
 
 def addApps(vmanage, appVPN):
@@ -210,8 +207,8 @@ def addApps(vmanage, appVPN):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/manage/apps"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, appVPN)
+    endpoint = f"dataservice/template/cloudx/manage/apps"
+    response = vmanage.apiCall("POST", endpoint, appVPN)
     return response
 
 def sitePerApp(vmanage, appName, vpnId):
@@ -228,6 +225,6 @@ def sitePerApp(vmanage, appName, vpnId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/cloudx/status?appName={appName}&vpnId={vpnId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/cloudx/status?appName={appName}&vpnId={vpnId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
