@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getBanner(vmanage):
     """
     Retrieve banner
@@ -13,8 +10,8 @@ def getBanner(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/banner"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/settings/banner"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getSessionTimout(vmanage):
@@ -29,8 +26,8 @@ def getSessionTimout(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/clientSessionTimeout"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/settings/clientSessionTimeout"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createAnalyticsDataFile(vmanage):
@@ -45,8 +42,8 @@ def createAnalyticsDataFile(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/configuration/analytics/dca"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/settings/configuration/analytics/dca"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def getCertConfig(vmanage, settingType):
@@ -62,8 +59,8 @@ def getCertConfig(vmanage, settingType):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/configuration/certificate/{settingType}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/settings/configuration/certificate/{settingType}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editCertConfig(vmanage, certConfig, settingType):
@@ -80,8 +77,8 @@ def editCertConfig(vmanage, certConfig, settingType):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/configuration/certificate/{settingType}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, certConfig)
+    endpoint = f"dataservice/settings/configuration/certificate/{settingType}"
+    response = vmanage.apiCall("PUT", endpoint, certConfig)
     return response
 
 def newCertConfig(vmanage, certConfig, settingType):
@@ -98,8 +95,8 @@ def newCertConfig(vmanage, certConfig, settingType):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/configuration/certificate/{settingType}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, certConfig)
+    endpoint = f"dataservice/settings/configuration/certificate/{settingType}"
+    response = vmanage.apiCall("POST", endpoint, certConfig)
     return response
 
 def getGoogleMapKey(vmanage):
@@ -114,8 +111,8 @@ def getGoogleMapKey(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/configuration/googleMapKey"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/settings/configuration/googleMapKey"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getMaintenanceWindow(vmanage):
@@ -130,8 +127,8 @@ def getMaintenanceWindow(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/configuration/maintenanceWindow"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/settings/configuration/maintenanceWindow"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getConfigBySettingType(vmanage, settingType):
@@ -147,8 +144,8 @@ def getConfigBySettingType(vmanage, settingType):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/configuration/{settingType}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/settings/configuration/{settingType}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editConfig(vmanage, configSetting, settingType):
@@ -165,8 +162,8 @@ def editConfig(vmanage, configSetting, settingType):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/configuration/{settingType}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, configSetting)
+    endpoint = f"dataservice/settings/configuration/{settingType}"
+    response = vmanage.apiCall("PUT", endpoint, configSetting)
     return response
 
 def newConfig(vmanage, configSetting, settingType):
@@ -183,6 +180,6 @@ def newConfig(vmanage, configSetting, settingType):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/settings/configuration/{settingType}"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, configSetting)
+    endpoint = f"dataservice/settings/configuration/{settingType}"
+    response = vmanage.apiCall("POST", endpoint, configSetting)
     return response
