@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def requestDNSSecActions(vmanage, action):
     """
     Request DNS-Sec actions
@@ -14,8 +11,8 @@ def requestDNSSecActions(vmanage, action):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/fedramp/dnssec/actions?action={action}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/fedramp/dnssec/actions?action={action}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def configureDNSSec(vmanage, request):
     """
@@ -30,8 +27,8 @@ def configureDNSSec(vmanage, request):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/fedramp/dnssec/config"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, request)
+    endpoint = f"dataservice/fedramp/dnssec/config"
+    response = vmanage.apiCall("POST", endpoint, request)
     return response
 def getDNSSecStatus(vmanage):
     """
@@ -45,8 +42,8 @@ def getDNSSecStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/fedramp/dnssec/status"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/fedramp/dnssec/status"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def configFedrampMode(vmanage, mode):
     """
@@ -61,8 +58,8 @@ def configFedrampMode(vmanage, mode):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/fedramp/status"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, mode)
+    endpoint = f"dataservice/fedramp/status"
+    response = vmanage.apiCall("POST", endpoint, mode)
     return response
 def requestWazuhActions(vmanage, action):
     """
@@ -77,8 +74,8 @@ def requestWazuhActions(vmanage, action):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/fedramp/wazuh/actions?action={action}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/fedramp/wazuh/actions?action={action}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def configureWazuhClient(vmanage, wazhuhConfig):
     """
@@ -93,8 +90,8 @@ def configureWazuhClient(vmanage, wazhuhConfig):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/fedramp/wazuh/config"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, wazhuhConfig)
+    endpoint = f"dataservice/fedramp/wazuh/config"
+    response = vmanage.apiCall("POST", endpoint, wazhuhConfig)
     return response
 def getWazuhAgentStatus(vmanage):
     """
@@ -108,6 +105,6 @@ def getWazuhAgentStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/fedramp/wazuh/status"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/fedramp/wazuh/status"
+    response = vmanage.apiCall("GET", endpoint)
     return response
