@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def onboardMDP(vmanage, onboard):
     """
     Start MDP onboarding operation
@@ -14,8 +11,8 @@ def onboardMDP(vmanage, onboard):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/onboard"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, onboard)
+    endpoint = f"dataservice/mdp/onboard"
+    response = vmanage.apiCall("POST", endpoint, onboard)
     return response
 
 def getOnboardStatus(vmanage):
@@ -30,8 +27,8 @@ def getOnboardStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/onboard/status"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/mdp/onboard/status"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def updateOnboardingPayload(vmanage, onboard, nmsId):
@@ -48,6 +45,6 @@ def updateOnboardingPayload(vmanage, onboard, nmsId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/onboard/{nmsId}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, onboard)
+    endpoint = f"dataservice/mdp/onboard/{nmsId}"
+    response = vmanage.apiCall("PUT", endpoint, onboard)
     return response
