@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getUTDDataplaneConfig(vmanage, deviceId):
     """
     Get data plane config from Device
@@ -14,8 +11,8 @@ def getUTDDataplaneConfig(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/dataplane-config?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/dataplane-config?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDDataplaneGlobal(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getUTDDataplaneGlobal(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/dataplane-global?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/dataplane-global?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDDataplaneStats(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getUTDDataplaneStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/dataplane-stats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/dataplane-stats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDDataplaneStatsSummary(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getUTDDataplaneStatsSummary(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/dataplane-stats-summary?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/dataplane-stats-summary?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDEngineInstanceStatus(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getUTDEngineInstanceStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/engine-instance-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/engine-instance-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDEngineStatus(vmanage, deviceId):
     """
@@ -94,8 +91,8 @@ def getUTDEngineStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/engine-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/engine-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDFileAnalysisStatus(vmanage, deviceId):
     """
@@ -110,8 +107,8 @@ def getUTDFileAnalysisStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/file-analysis-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/file-analysis-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDFileReputationStatus(vmanage, deviceId):
     """
@@ -126,8 +123,8 @@ def getUTDFileReputationStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/file-reputation-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/file-reputation-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDIpsUpdateStatus(vmanage, deviceId):
     """
@@ -142,8 +139,8 @@ def getUTDIpsUpdateStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/ips-update-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/ips-update-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSignatureVersionInfo(vmanage, deviceId):
     """
@@ -158,8 +155,8 @@ def getSignatureVersionInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/signature/version/details?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/signature/version/details?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDUrlfConnectionStatus(vmanage, deviceId):
     """
@@ -174,8 +171,8 @@ def getUTDUrlfConnectionStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/urlf-con-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/urlf-con-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDUrlfUpdateStatus(vmanage, deviceId):
     """
@@ -190,8 +187,8 @@ def getUTDUrlfUpdateStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/urlf-update-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/urlf-update-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUTDVersionStatus(vmanage, deviceId):
     """
@@ -206,6 +203,6 @@ def getUTDVersionStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/utd/version-status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/utd/version-status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
